SharedIncin

Struct SharedIncin 

pub struct SharedIncin<T> { /* private fields */ }
The shared incinerator used by Stack. You may want to use this type in order to reduce memory consumption of the minimal space required by the incinerator. However, garbage items may be hold for longer time than they would if no shared incinerator were used.

Implementations

Source

impl<T> SharedIncin<T>

pub fn new() -> Self

Creates a new shared incinerator for Stack.

pub fn clear(&mut self)

Tries to clear the incinerator garbage list in the best possible way given the runtime status of this incinerator.