pub struct SharedIncin<T> { /* private fields */ }Expand description
The shared incinerator used by Set. You may want to use this type
in order to reduce memory consumption of the minimal space required by the
incinerator. However, garbage items may be hold for longer time than they
would if no shared incinerator were used.
Implementations